@@ -8,6 +8,7 @@ KEY_AUTHORIZE_LOGIN = "authorize-login"
 KEY_AUTHORIZE_LOGOUT = "authorize-logout"
 KEY_BRIGHTNESS = "brightness"
 KEY_CLEAR = "clear"
+KEY_CLIENT = "client"
 KEY_COLOR = "color"
 KEY_COMMAND = "command"
 KEY_COMPONENT = "component"
@@ -32,6 +33,8 @@ KEY_LED_STREAM_START = "ledstream-start"
 KEY_LED_STREAM_STOP = "ledstream-stop"
 KEY_LEDS = "leds"
 KEY_LED_MAPPING = "imageToLedMapping"
+KEY_LOADED_STATE = "loaded-state"
+KEY_LOGGED_IN = "logged-in"
 KEY_LOGIN = "login"
 KEY_LOGOUT = "logout"
 KEY_NAME = "name"
@@ -50,6 +53,7 @@ KEY_SET_VIDEOMODE = "videoMode"
 KEY_SERVERINFO = "serverinfo"
 KEY_SOURCESELECT = "sourceselect"
 KEY_START_INSTANCE = "startInstance"
+KEY_STATE_LOADED = "startInstance"
 KEY_STOP_INSTANCE = "stopInstance"
 KEY_SUBCOMMAND = "subcommand"
 KEY_SUBSCRIBE = "subscribe"
@@ -87,7 +91,7 @@ KEY_COMPONENTID_EXTERNAL_SOURCES = [
 ]
 
 DEFAULT_INSTANCE = 0
-DEFAULT_CONNECTION_RETRY_DELAY = 30
+DEFAULT_CONNECTION_RETRY_DELAY_SECS = 30
 DEFAULT_TIMEOUT_SECS = 5
 DEFAULT_ORIGIN = "hyperion-py"
 DEFAULT_PORT = 19444
